# -*- coding: utf-8 -*-

from flask_nemo.plugin import PluginPrototype
from pkg_resources import resource_filename


class PerseusNemoUi(PluginPrototype):
    """
        The Breadcrumb plugin is enabled by default in Nemo.
        It can be overwritten or removed. It simply adds a breadcrumb

    """
    HAS_AUGMENT_RENDER = False
    TEMPLATES = {"main": resource_filename("perseus_nemo_ui", "data/templates")}
    CSS = [resource_filename("perseus_nemo_ui","data/assets/css/theme-ext.css")]
    STATICS = [
        resource_filename("perseus_nemo_ui","data/assets/images/rev_running_man.png")
    ]




from setuptools import setup, find_packages

setup(
    name='perseus_nemo_ui',
    version="0.0.2",
    packages=find_packages(exclude=["examples", "tests"]),
    url='https://github.com/PerseusDL/perseus_nemo_ui',
    license='GNU GPL',
    author='Bridget Almas',
    author_email='balmas@gmail.com',
    description='Plugin for Perseus UI for Nemo',
    test_suite="tests",
    install_requires=[
        "flask_nemo>=1.0.0b1"
    ],
    tests_require=[
        "capitains_nautilus>=0.0.5"
    ],
    include_package_data=True,
    zip_safe=False
)
